@@ -4,19 +4,19 @@
 # Python by Baruch Even. It was rewritten by Dave St.Germain for speed.
 #
 # The MIT License (MIT)
-# 
+#
 # Copyright (c) 2013 Dave St.Germain
-# 
+#
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be included in
 # all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -39,14 +39,14 @@ else:
 
 
 __all__ = ['jsmin', 'JavascriptMinify']
-__version__ = '2.0.11'
+__version__ = '2.1.6'
 
 
-def jsmin(js):
+def jsmin(js, **kwargs):
     """
     returns a minified version of the javascript string
     """
-    if not is_3:        
+    if not is_3:
         if cStringIO and not isinstance(js, unicode):
             # strings can use cStringIO for a 3x performance
             # improvement, but unicode (in python2) cannot
@@ -57,7 +57,7 @@ def jsmin(js):
         klass = io.StringIO
     ins = klass(js)
     outs = klass()
-    JavascriptMinify(ins, outs).minify()
+    JavascriptMinify(ins, outs, **kwargs).minify()
     return outs.getvalue()
 
 
@@ -67,23 +67,26 @@ class JavascriptMinify(object):
     to an output stream
     """
 
-    def __init__(self, instream=None, outstream=None):
+    def __init__(self, instream=None, outstream=None, quote_chars="'\""):
         self.ins = instream
         self.outs = outstream
+        self.quote_chars = quote_chars
 
     def minify(self, instream=None, outstream=None):
         if instream and outstream:
             self.ins, self.outs = instream, outstream
-        
+
         self.is_return = False
         self.return_buf = ''
-        
+
         def write(char):
             # all of this is to support literal regular expressions.
             # sigh
             if char in 'return':
                 self.return_buf += char
                 self.is_return = self.return_buf == 'return'
+            else:
+                self.return_buf = ''
             self.outs.write(char)
             if self.is_return:
                 self.return_buf = ''
@@ -92,73 +95,26 @@ class JavascriptMinify(object):
 
         space_strings = "abcdefghijklmnopqrstuvwxyz"\
         "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_$\\"
-        starters, enders = '{[(+-', '}])+-"\''
-        newlinestart_strings = starters + space_strings
-        newlineend_strings = enders + space_strings
+        self.space_strings = space_strings
+        starters, enders = '{[(+-', '}])+-/' + self.quote_chars
+        newlinestart_strings = starters + space_strings + self.quote_chars
+        newlineend_strings = enders + space_strings + self.quote_chars
+        self.newlinestart_strings = newlinestart_strings
+        self.newlineend_strings = newlineend_strings
+
         do_newline = False
         do_space = False
         escape_slash_count = 0
-        doing_single_comment = False
-        previous_before_comment = ''
-        doing_multi_comment = False
-        in_re = False
         in_quote = ''
         quote_buf = []
-        
-        previous = read(1)
-        if previous == '\\':
-            escape_slash_count += 1
-        next1 = read(1)
-        if previous == '/':
-            if next1 == '/':
-                doing_single_comment = True
-            elif next1 == '*':
-                doing_multi_comment = True
-                previous = next1
-                next1 = read(1)
-            else:
-                in_re = True  # literal regex at start of script
-                write(previous)
-        elif not previous:
-            return
-        elif previous >= '!':
-            if previous in "'\"":
-                in_quote = previous
-            write(previous)
-            previous_non_space = previous
-        else:
-            previous_non_space = ' '
-        if not next1:
-            return
 
-        while 1:
+        previous = ';'
+        previous_non_space = ';'
+        next1 = read(1)
+
+        while next1:
             next2 = read(1)
-            if not next2:
-                last = next1.strip()
-                if not (doing_single_comment or doing_multi_comment)\
-                    and last not in ('', '/'):
-                    if in_quote:
-                        write(''.join(quote_buf))
-                    write(last)
-                break
-            if doing_multi_comment:
-                if next1 == '*' and next2 == '/':
-                    doing_multi_comment = False
-                    if previous_before_comment and previous_before_comment in space_strings:
-                        do_space = True
-                    next2 = read(1)
-            elif doing_single_comment:
-                if next1 in '\r\n':
-                    doing_single_comment = False
-                    while next2 in '\r\n':
-                        next2 = read(1)
-                        if not next2:
-                            break
-                    if previous_before_comment in ')}]':
-                        do_newline = True
-                    elif previous_before_comment in space_strings:
-                        write('\n')
-            elif in_quote:
+            if in_quote:
                 quote_buf.append(next1)
 
                 if next1 == in_quote:
@@ -172,19 +128,9 @@ class JavascriptMinify(object):
                         in_quote = ''
                         write(''.join(quote_buf))
             elif next1 in '\r\n':
-                if previous_non_space in newlineend_strings \
-                    or previous_non_space > '~':
-                    while 1:
-                        if next2 < '!':
-                            next2 = read(1)
-                            if not next2:
-                                break
-                        else:
-                            if next2 in newlinestart_strings \
-                                or next2 > '~' or next2 == '/':
-                                do_newline = True
-                            break
-            elif next1 < '!' and not in_re:
+                next2, do_newline = self.newline(
+                    previous_non_space, next2, do_newline)
+            elif next1 < '!':
                 if (previous_non_space in space_strings \
                     or previous_non_space > '~') \
                     and (next2 in space_strings or next2 > '~'):
@@ -198,45 +144,120 @@ class JavascriptMinify(object):
             elif next1 == '/':
                 if do_space:
                     write(' ')
-                if in_re:
-                    if previous != '\\' or (not escape_slash_count % 2) or next2 in 'gimy':
-                        in_re = False
-                    write('/')
-                elif next2 == '/':                    
-                    doing_single_comment = True
-                    previous_before_comment = previous_non_space
+                if next2 == '/':
+                    # Line comment: treat it as a newline, but skip it
+                    next2 = self.line_comment(next1, next2)
+                    next1 = '\n'
+                    next2, do_newline = self.newline(
+                        previous_non_space, next2, do_newline)
                 elif next2 == '*':
-                    doing_multi_comment = True
-                    previous_before_comment = previous_non_space
-                    previous = next1
-                    next1 = next2
+                    self.block_comment(next1, next2)
                     next2 = read(1)
+                    if previous_non_space in space_strings:
+                        do_space = True
+                    next1 = previous
                 else:
-                    in_re = previous_non_space in '(,=:[?!&|;' or self.is_return  # literal regular expression
-                    write('/')
+                    if previous_non_space in '{(,=:[?!&|;' or self.is_return:
+                        self.regex_literal(next1, next2)
+                        # hackish: after regex literal next1 is still /
+                        # (it was the initial /, now it's the last /)
+                        next2 = read(1)
+                    else:
+                        write('/')
             else:
-                if do_space:
-                    do_space = False
-                    write(' ')
                 if do_newline:
                     write('\n')
                     do_newline = False
-                    
+                    do_space = False
+                if do_space:
+                    do_space = False
+                    write(' ')
+
                 write(next1)
-                if not in_re and next1 in "'\"":
+                if next1 in self.quote_chars:
                     in_quote = next1
                     quote_buf = []
 
+            if next1 >= '!':
+                previous_non_space = next1
+
+            if next1 == '\\':
+                escape_slash_count += 1
+            else:
+                escape_slash_count = 0
+
             previous = next1
             next1 = next2
 
-            if previous >= '!':
-                previous_non_space = previous
+    def regex_literal(self, next1, next2):
+        assert next1 == '/'  # otherwise we should not be called!
 
-            if previous == '\\':
-                escape_slash_count += 1
-            else:
-                escape_slash_count = 0
+        self.return_buf = ''
+
+        read = self.ins.read
+        write = self.outs.write
+
+        in_char_class = False
+
+        write('/')
+
+        next = next2
+        while next != '/' or in_char_class:
+            write(next)
+            if next == '\\':
+                write(read(1))  # whatever is next is escaped
+            elif next == '[':
+                write(read(1))  # character class cannot be empty
+                in_char_class = True
+            elif next == ']':
+                in_char_class = False
+            next = read(1)
+
+        write('/')
+
+    def line_comment(self, next1, next2):
+        assert next1 == next2 == '/'
+
+        read = self.ins.read
+
+        while next1 and next1 not in '\r\n':
+            next1 = read(1)
+        while next1 and next1 in '\r\n':
+            next1 = read(1)
+
+        return next1
+
+    def block_comment(self, next1, next2):
+        assert next1 == '/'
+        assert next2 == '*'
+
+        read = self.ins.read
+
+        # Skip past first /* and avoid catching on /*/...*/
+        next1 = read(1)
+        next2 = read(1)
+        while next1 != '*' or next2 != '/':
+            next1 = next2
+            next2 = read(1)
+
+    def newline(self, previous_non_space, next2, do_newline):
+        read = self.ins.read
+
+        if previous_non_space and (
+                        previous_non_space in self.newlineend_strings
+                        or previous_non_space > '~'):
+            while 1:
+                if next2 < '!':
+                    next2 = read(1)
+                    if not next2:
+                        break
+                else:
+                    if next2 in self.newlinestart_strings \
+                            or next2 > '~' or next2 == '/':
+                        do_newline = True
+                    break
+
+        return next2, do_newline
 
 if __name__ == '__main__':
 	import sys, os, glob
@@ -250,3 +271,4 @@ if __name__ == '__main__':
 	minifier = JavascriptMinify(sys.stdin, sys.stdout)
 	minifier.minify()
 	sys.stdout.write('\n')
+
