@@ -322,6 +322,7 @@ typedef struct {
 	Tscantable *st;				/* NULL or complete */
 	gchar *smartindentchars;
 	gchar *smartoutdentchars;
+	gchar *smartselectionchars;
 #ifdef HAVE_LIBENCHANT
 	gboolean default_spellcheck;
 	gboolean spell_decode_entities;
@@ -346,6 +347,8 @@ typedef enum {
 	BTV_COLOR_CURSOR,
 	BTV_COLOR_SELECTION,
 	BTV_COLOR_CURSOR_HIGHLIGHT,
+	BTV_COLOR_MARGIN_FG,
+	BTV_COLOR_MARGIN_BG,
 /*	BTV_COLOR_SEARCH_BG,
 	BTV_COLOR_SEARCH_FG,*/
 	BTV_COLOR_COUNT
@@ -414,6 +417,9 @@ struct _BluefishTextView {
 	guint needremovetags;	/* after we have removed all old highlighting, we set this to G_MAXUINT32, or to the
 									offset up to the point where we removed the old highlighting. but after a change that
 									needs highlighting we set this to the offset of the change. */
+	gint spacingtoclickstart;
+	gint spacingtoclickend;
+	
 	/* next three are used for margin painting */
 	gint margin_pixels_per_char;
 	gint margin_pixels_chars;
@@ -442,6 +448,7 @@ struct _BluefishTextViewClass {
 GType bluefish_text_view_get_type(void);
 const gchar *bluefish_text_view_get_lang_name(BluefishTextView *btv);
 gboolean bluefish_text_view_get_active_block_boundaries(BluefishTextView *btv, guint location, gboolean innerblock, GtkTextIter *so, GtkTextIter *eo);
+gboolean bluefish_text_view_get_active_identifier(BluefishTextView *btv, GtkTextIter *currentlocation, GtkTextIter *so, GtkTextIter *eo);
 gpointer bftextview2_get_block_at_boundary_location(BluefishTextView *btv, guint offset, GtkTextIter *it1, GtkTextIter *it2, GtkTextIter *it3, GtkTextIter *it4);
 gboolean bluefish_text_view_get_auto_complete(BluefishTextView * btv);
 void bluefish_text_view_set_auto_complete(BluefishTextView * btv, gboolean enable);
@@ -473,6 +480,9 @@ void bftextview2_schedule_scanning(BluefishTextView * btv);
 gboolean bluefish_text_view_in_comment(BluefishTextView * btv, GtkTextIter * its, GtkTextIter * ite);
 Tcomment *bluefish_text_view_get_comment(BluefishTextView * btv, GtkTextIter * it,
 										 Tcomment_type preferred_type);
+gboolean last_undo_is_spacingtoclick(BluefishTextView * btv);
+void bluefish_text_view_remove_spacingtoclick(BluefishTextView * btv);
+
 void bluefish_text_view_multiset(BluefishTextView * btv, gpointer doc, gint view_line_numbers,
 							gint view_blocks, gint autoindent, gint autocomplete, gint show_mbhl, gint enable_scanner);
 
