@@ -381,7 +381,12 @@ acwin_create(BluefishTextView * btv)
 	gtk_window_set_resizable(GTK_WINDOW(acw->win), FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(acw->win), 1);
 	gtk_window_set_decorated(GTK_WINDOW(acw->win), FALSE);
-	gtk_window_set_type_hint(GTK_WINDOW(acw->win), GDK_WINDOW_TYPE_HINT_POPUP_MENU);
+
+	/* setting the type hint makes wayland *not* create a subsurface (I learned that on IRC), and we need a 
+	subsurface, otherwise the popup can't be moved. we also need to make the window transient for the parent
+	for the wayland backend to create a subsurface */
+	/*gtk_window_set_type_hint(GTK_WINDOW(acw->win), GDK_WINDOW_TYPE_HINT_POPUP_MENU);*/
+	gtk_window_set_transient_for(GTK_WINDOW(acw->win), GTK_WINDOW(BFWIN(DOCUMENT(acw->btv->doc)->bfwin)->main_window));
 
 	acw->store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 	acw->tree = GTK_TREE_VIEW(gtk_tree_view_new_with_model(GTK_TREE_MODEL(acw->store)));
@@ -613,7 +618,7 @@ process_conditional_items(BluefishTextView * btv, Tfound *found, gint contextnum
 		guint pattern_id;
 		const gchar *string = tmplist->data;
 		GHashTable *hasht = g_array_index(master->bflang->st->contexts, Tcontext,contextnum).patternhash;
-		g_print("process_conditional_items, looking up %s in hashtable %p\n",string, hasht);
+		DBG_AUTOCOMP("process_conditional_items, looking up %s in hashtable %p\n",string, hasht);
 		pattern_id = GPOINTER_TO_INT(g_hash_table_lookup(hasht, string));
 		DBG_AUTOCOMP("process_conditional_items, got pattern_id=%d\n", pattern_id);
 		if (pattern_id && found) {
@@ -628,7 +633,7 @@ process_conditional_items(BluefishTextView * btv, Tfound *found, gint contextnum
 					
 					valid = test_condition(found->fcontext, found->fblock, pcond);
 					if (!valid) {
-						g_print("process_conditional_items, item %s is NOT VALID for autocompletion\n",string);
+						DBG_AUTOCOMP("process_conditional_items, item %s is NOT VALID for autocompletion\n",string);
 					}
 				}
 				tmpslist = g_slist_next(tmpslist);
