@@ -889,7 +889,7 @@ bfwin_gotoline_search_bar_close(Tbfwin *bfwin, gboolean clean_entry_only)
 
 		if (bfwin->simplesearch_snr3run) {
 			DEBUG_MSG("free simple search run %p\n", bfwin->simplesearch_snr3run);
-			snr3run_free(bfwin->simplesearch_snr3run, TRUE, FALSE);
+			simple_search_cancel_free(bfwin->simplesearch_snr3run);
 			bfwin->simplesearch_snr3run = NULL;
 		}
 	}
@@ -936,7 +936,7 @@ simplesearch_start(Tbfwin *bfwin, gboolean allow_single_char_search) {
 	tmpstr = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(bfwin->simplesearch_combo))));
 	if (bfwin->simplesearch_snr3run) {
 		DEBUG_MSG("free simple search run %p\n", bfwin->simplesearch_snr3run);
-		snr3run_free(bfwin->simplesearch_snr3run, TRUE, FALSE);
+		simple_search_cancel_free(bfwin->simplesearch_snr3run);
 		bfwin->simplesearch_snr3run=NULL;
 	}
 	if (tmpstr && tmpstr[0]!='\0' && (allow_single_char_search || tmpstr[1] != '\0')) {
@@ -1561,7 +1561,7 @@ bfwin_key_release_event(GtkWidget *widget, GdkEventKey  *kevent, gpointer   user
 }
 
 void
-bfwin_create_main(Tbfwin * bfwin)
+bfwin_create_main(Tbfwin * bfwin, gboolean with_new_doc)
 {
 	GtkWidget *vbox;
 	DEBUG_MSG("bfwin_create_main, bfwin=%p, main_window_w=%d\n", bfwin, main_v->globses.main_window_w);
@@ -1705,7 +1705,8 @@ bfwin_create_main(Tbfwin * bfwin)
 	}
 	/* everything is ready - we can start loading documents */
 	/* start to open an empty doc */
-	file_new_cb(NULL, bfwin);
+	if (with_new_doc)
+		file_new_cb(NULL, bfwin);
 
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK(bfwin->notebook), TRUE);
 	/* don't use show_all since some widgets are and should be hidden */
@@ -1728,7 +1729,12 @@ bfwin_create_main(Tbfwin * bfwin)
 
 #ifdef MAC_INTEGRATION
 /* first move all accelerators away from <control> to <command>, and then in a second run
-move the <alt> accelerators to <control> (alt doesn't work on osx) */
+move the <alt> accelerators to <control> (alt doesn't work on osx)
+* Modifiers mapping on osx
+* MOD1 = Option/Alt
+* MOD2 = META = Command
+* CONTROL = Control
+ */
 static void
 osx_accel_map_foreach_controltometa_lcb(gpointer data, const gchar * accel_path, guint accel_key,
 										GdkModifierType accel_mods, gboolean changed)
@@ -1869,7 +1875,7 @@ bfwin_all_statusbar_message(const gchar * message, gint seconds)
 }
 
 Tbfwin *
-bfwin_window_new_with_project(Tproject * project)
+bfwin_window_new_with_project(Tproject * project, gboolean with_new_doc)
 {
 	Tbfwin *bfwin = g_new0(Tbfwin, 1);
 
@@ -1882,7 +1888,7 @@ bfwin_window_new_with_project(Tproject * project)
 	DEBUG_MSG("bfwin_window_new_with_project, bfwin=%p, bfwin->session=%p, (from project %p)\n", bfwin,
 			  bfwin->session, project);
 
-	bfwin_create_main(bfwin);
+	bfwin_create_main(bfwin, with_new_doc);
 	main_v->bfwinlist = g_list_append(main_v->bfwinlist, bfwin);
 	bfwin_show_main(bfwin);
 
@@ -1900,7 +1906,7 @@ bfwin_window_new(void)
 	bfwin->bmarkdata = main_v->bmarkdata;
 	DEBUG_MSG("bfwin_window_new, bfwin=%p, (from main_v)\n", bfwin);
 
-	bfwin_create_main(bfwin);
+	bfwin_create_main(bfwin, TRUE);
 	main_v->bfwinlist = g_list_append(main_v->bfwinlist, bfwin);
 	bfwin_show_main(bfwin);
 
