@@ -313,7 +313,7 @@ entity_dialog(Tbfwin * bfwin, Tentmode mode, Tentitysetting * eset)
 		ew->IE_apos_workaround =
 			gtk_check_button_new_with_mnemonic(_("Work around missing &apos; entity on IE"));
 		gtk_box_pack_start(GTK_BOX(vbox), ew->IE_apos_workaround, FALSE, FALSE, 0);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ew->xml), eset->IE_apos_workaround);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ew->IE_apos_workaround), eset->IE_apos_workaround);
 	} else {
 		ew->IE_apos_workaround = NULL;
 	}
@@ -394,19 +394,21 @@ entity_init(void)
 }
 
 static const gchar *entities_plugin_ui =
-	"<ui>"
-	"  <menubar name='MainMenu'>"
-	"    <menu action='ToolsMenu'>"
-	"      <separator/>"
-	"      <menuitem action='CharactersToEntities'/>"
-	"      <menuitem action='EntitiesToCharacters'/>"
-	"      <menuitem action='URLDecode'/>"
-	"      <menuitem action='URLEncode'/>"
-	"      <menuitem action='ToLowercase'/>"
-	"      <menuitem action='ToUppercase'/>"
-	"    </menu>"
-	"  </menubar>"
-	"</ui>";
+"<ui>"
+	"<menubar name='MainMenu'>"
+		"<menu action='ToolsMenu'>"
+			"<menu action='ToolsConvert'>"
+				"<separator/>"
+				"<menuitem action='CharactersToEntities'/>"
+				"<menuitem action='EntitiesToCharacters'/>"
+				"<menuitem action='URLDecode'/>"
+				"<menuitem action='URLEncode'/>"
+				"<menuitem action='ToLowercase'/>"
+				"<menuitem action='ToUppercase'/>"
+			"</menu>"
+		"</menu>"
+	"</menubar>"
+"</ui>";
 
 static void
 entity_initgui(Tbfwin * bfwin)
