@@ -431,11 +431,9 @@ project_open_from_file(Tbfwin * bfwin, GFile * fromuri)
 	} else {
 		/* we will open a new Bluefish window for this project */
 		DEBUG_MSG("project_open_from_file, we need a new window\n");
-		prwin = bfwin_window_new_with_project(prj);
-		if (prwin->current_document)
-			doc_destroy(prwin->current_document, TRUE); /*new window is created with empty doc, so we destroy it TODO move empty tab creation from bfwin_create_main() */
+		prwin = bfwin_window_new_with_project(prj, FALSE);
 	}
-	tmplist = g_list_last(prj->files);
+	tmplist = g_list_first(prj->files);
 	gint doc_index = 0;
 	gint i =0;
 	gint cursor_offset = -1;
@@ -470,7 +468,7 @@ project_open_from_file(Tbfwin * bfwin, GFile * fromuri)
 				doc_new_from_uri(prwin, uri, NULL, TRUE, TRUE, -1, goto_offset, cursor_offset, FALSE, FALSE);
 			}
 			g_object_unref(uri);
-			tmplist = g_list_previous(tmplist);
+			tmplist = g_list_next(tmplist);
 			i++;
 		}
 		/* Now switch to tab that holds last active document from previous session */
@@ -624,7 +622,7 @@ project_edit_ok_clicked_lcb(GtkWidget * widget, Tprojecteditor * pred)
 	string_apply(&prj->name, pred->entries[name]);
 	sessionprefs_apply(&pred->sprefs, pred->project->session);
 	if (pred->bfwin == NULL) {
-		pred->bfwin = bfwin_window_new_with_project(pred->project);
+		pred->bfwin = bfwin_window_new_with_project(pred->project, TRUE);
 		pred->bfwin->session = pred->project->session;
 		setup_bfwin_for_project(pred->bfwin, NULL);
 	} else {
