@@ -486,6 +486,9 @@ props_init_main(GHashTable * config_rc)
 	init_prop_integer(&config_rc, &main_v->props.open_in_running_bluefish, "open_in_running_bluefish:", 1,
 					  TRUE);
 	init_prop_integer(&config_rc, &main_v->props.open_in_new_window, "open_in_new_window:", 1, TRUE);
+#ifdef WIN32
+	init_prop_integer(&config_rc, &main_v->props.win32_ipcport, "win32_ipcport:", 0, TRUE);
+#endif
 	init_prop_integer(&config_rc, &main_v->props.register_recent_mode, "register_recent_mode:", 2, TRUE);
 	init_prop_integer(&config_rc, &main_v->props.recent_means_recently_closed, "recent_means_recently_closed:", 1, TRUE);
 	init_prop_arraylist(&config_rc, &main_v->props.plugin_config, "plugin_config:", 3, TRUE);
@@ -1091,7 +1094,7 @@ rcfile_save_main(void)
 void
 rcfile_check_directory(void)
 {
-	GFile *file, *rcpath;
+	GFile *file, *rcpath, *rcsubpath;
 	GFileInfo *finfo;
 	GError *gerror = NULL;
 
@@ -1109,6 +1112,12 @@ rcfile_check_directory(void)
 			g_warning("%s", gerror->message);
 			g_error_free(gerror);
 		}
+		rcsubpath = g_file_get_child(rcpath, "templates");
+		g_file_make_directory(rcsubpath, NULL, NULL);
+		g_object_unref(rcsubpath);
+		rcsubpath = g_file_get_child(rcpath, "autosave");
+		g_file_make_directory(rcsubpath, NULL, NULL);
+		g_object_unref(rcsubpath);
 	}
 
 	g_object_unref(rcpath);
@@ -1267,7 +1276,8 @@ return_session_configlist(GHashTable * configlist, Tsessionvars * session)
 
 	init_prop_integer(&configlist, &session->snr3_type, "snr_type:", 1, FALSE);
 	init_prop_integer(&configlist, &session->snr3_replacetype, "snr_replacetype:", 1, FALSE);
-	init_prop_integer(&configlist, &session->snr3_scope, "snr_scope:", 1, FALSE);
+	/*	no longer stored, see https://sourceforge.net/p/bluefish/tickets/26/ 
+	init_prop_integer(&configlist, &session->snr3_scope, "snr_scope:", 1, FALSE);*/
 	init_prop_integer(&configlist, &session->snr3_casesens, "snr_casesens:", 1, FALSE);
 	init_prop_integer(&configlist, &session->snr3_showinoutputbox, "snr_showinoutputbox:", 1, FALSE);
 	init_prop_integer(&configlist, &session->snr3_ignorebackupfiles, "snr_ignorebackupfiles:", 1, FALSE);
