@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * snr3.c - search and replace
  *
- * Copyright (C) 2011,2012,2013,2014,2017,2019 Olivier Sessink
+ * Copyright (C) 2011,2012,2013,2014,2017,2019,2020 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -510,7 +510,7 @@ snr3_run_loop_idle_func(Truninidle *rii)
 {
 	Tsnr3run *s3run=rii->s3run;
 	gboolean cont;
-	DEBUG_MSG("snr3_run_loop_idle_func, next loop\n");
+	DEBUG_MSG("snr3_run_loop_idle_func, next loop for rii=%p, s3run=%p\n",rii,s3run);
 	if (s3run->type == snr3type_string)
 		cont = backend_string_loop(s3run, FALSE);
 	else
@@ -525,12 +525,12 @@ snr3_run_loop_idle_func(Truninidle *rii)
 		if (S3RESULT(s3run->results.tail->data)->doc == rii->doc)
 			s3run->resultnumdoc++;
 	}
-
 	g_free(s3run->curbuf);
 	s3run->curbuf=NULL;
 	s3run->idle_id = 0;
 	DEBUG_MSG("snr3_run_loop_idle_func, s3run=%p, ready, call queue_worker_ready()\n",s3run);
 	queue_worker_ready(&s3run->idlequeue);
+	DEBUG_MSG("snr3_run_loop_idle_func, call snr3run_unrun (which calls the callback for s3run=%p) and then slice_free rii=%p and return FALSE\n",s3run,rii);
 	snr3run_unrun(s3run); /* unrun currently only calls the callback if the refcount is zero, we can run that from here too ??? */
 	g_slice_free(Truninidle, rii);
 	return FALSE;
@@ -539,7 +539,7 @@ snr3_run_loop_idle_func(Truninidle *rii)
 void
 snr3_queue_run(gpointer data) {
 	Truninidle *rii=data;
-	DEBUG_MSG("snr3_queue_run, s3run=%p, doc=%p\n",rii->s3run, rii->doc);
+	DEBUG_MSG("snr3_queue_run, rii=%p, s3run=%p, doc=%p\n",rii,rii->s3run, rii->doc);
 
 	if (rii->update) {
 		GList *tmplist=rii->s3run->results.head;
@@ -573,7 +573,7 @@ snr3_queue_run(gpointer data) {
 			doc_unre_new_group(rii->doc);
 		}
 	}
-
+	DEBUG_MSG("snr3_queue_run, add idle callback for rii=%p with s3run=%p\n",rii,rii->s3run);
 	rii->s3run->idle_id = g_idle_add_full(G_PRIORITY_DEFAULT_IDLE,(GSourceFunc)snr3_run_loop_idle_func,rii,NULL);
 }
 
@@ -594,6 +594,7 @@ snr3_run_in_doc(Tsnr3run *s3run, Tdocument *doc, gint so, gint eo, gboolean upda
 		return;
 
 	rii = g_slice_new(Truninidle);
+	DEBUG_MSG("snr3_run_in_doc, created rii=%p to run s3run=%p\n",rii,s3run);
 	rii->doc = doc;
 	rii->s3run=s3run;
 	g_atomic_int_inc(&s3run->runcount);
@@ -604,7 +605,7 @@ snr3_run_in_doc(Tsnr3run *s3run, Tdocument *doc, gint so, gint eo, gboolean upda
 		rii->s3run->callback = update_callback;
 	}
 
-	DEBUG_MSG("s3run=%p, push doc %p on the idlequeue, len=%d, update=%d\n",s3run, doc,s3run->idlequeue.q.length, update);
+	DEBUG_MSG("snr3_run_in_doc, push rii=%p, s3run=%p, doc=%p on the idlequeue, len=%d, update=%d\n",rii, s3run, doc,s3run->idlequeue.q.length, update);
 	queue_push(&s3run->idlequeue, rii);
 }
 
@@ -738,13 +739,25 @@ snr3_run(Tsnr3run *s3run, TSNRWin *snrwin, Tdocument *doc, void (*callback)(void
 	}
 }
 
+static void
+idlequeue_cancel_freefunc(gpointer data, gpointer user_data)
+{
+	Truninidle *rii=data;
+	snr3run_unrun(rii->s3run);
+	g_slice_free(Truninidle, rii);
+}
+
 static void
 snr3_cancel_run(Tsnr3run *s3run) {
 	DEBUG_MSG("snr3_cancel_run, started for %p\n",s3run);
+	/* remove anthing that has not yet been started on the idlequeue */
+	queue_cancel(&s3run->idlequeue, idlequeue_cancel_freefunc, s3run);
+	DEBUG_MSG("snr3_cancel_run, after queue_cancel, runcount=%d\n",s3run->runcount);
 	if (s3run->idle_id) {
 		DEBUG_MSG("remove idle_id %d\n", s3run->idle_id);
 		g_source_remove(s3run->idle_id);
 		queue_worker_ready(&s3run->idlequeue);
+		DEBUG_MSG("snr3_cancel_run, after queue_worker_ready, runcount=%d\n",s3run->runcount);
 		g_atomic_int_set(&s3run->runcount,0);
 		/* TODO: BUG: MEMLEAK: the Truninidle is not free'ed now !?!?!?! */
 		s3run->idle_id=0;
@@ -777,12 +790,15 @@ snr3run_resultcleanup(Tsnr3run *s3run, gboolean clear_outputbox)
 	}
 }
 
-/* called from bfwin.c for simplesearch */
-void
+static void
 snr3run_free(Tsnr3run *s3run, gboolean remove_highlights, gboolean clear_outputbox) {
 	DEBUG_MSG("snr3run_free, started for %p\n",s3run);
-	if (s3run->curbuf)
+	
+	queue_cancel(&s3run->idlequeue, idlequeue_cancel_freefunc, s3run);
+	
+	if (s3run->curbuf) {
 		g_free(s3run->curbuf);
+	}
 	bfwin_current_document_change_remove_by_data(s3run->bfwin, s3run);
 	bfwin_document_insert_text_remove_by_data(s3run->bfwin, s3run);
 	bfwin_document_delete_range_remove_by_data(s3run->bfwin, s3run);
@@ -1085,6 +1101,7 @@ snr3run_new(Tbfwin *bfwin, gpointer dialog)
 {
 	Tsnr3run *s3run;
 	s3run = g_slice_new0(Tsnr3run);
+	DEBUG_MSG("snr3run_new, created s3run=%p\n",s3run);
 	s3run->bfwin = bfwin;
 	s3run->dialog = dialog;
 	g_queue_init(&s3run->results);
@@ -1136,7 +1153,7 @@ activate_simple_search(void *data) {
 }
 
 static void
-simple_search_add_to_history(Tbfwin *bfwin, const gchar *string)
+search_add_or_extend_history(Tbfwin *bfwin, const gchar *string)
 {
 	if (!string || string[0] == '\0')
 		return;
@@ -1166,7 +1183,7 @@ gpointer simple_search_run(Tbfwin *bfwin, const gchar *string, Tsnr3type type
 
 	s3run = snr3run_new(bfwin, NULL);
 	snr3run_multiset(s3run, string, NULL, type,snr3replace_string,snr3scope_doc, FALSE);
-	simple_search_add_to_history(bfwin, string);
+	search_add_or_extend_history(bfwin, string);
 	s3run->dotmatchall = dotmatchall;
 	s3run->is_case_sens = casesens;
 	s3run->escape_chars = unescape;
@@ -1183,6 +1200,15 @@ simple_search_next(Tbfwin *bfwin)
 		snr3_run_go(((Tsnr3run *)bfwin->simplesearch_snr3run), TRUE);
 	}
 }
+
+void
+simple_search_cancel_free(void *data) {
+	Tsnr3run *s3run=data;
+	/* first cancel anything running in either an idle loop OR on the queue */ 
+	snr3_cancel_run(s3run);
+	/* now free */
+	snr3run_free(s3run, TRUE, FALSE);
+}
 /******************************************************/
 /*********** end of simple search *********************/
 /******************************************************/
@@ -1267,6 +1293,11 @@ snr3run_init_from_gui(TSNRWin *snrwin, Tsnr3run *s3run)
 		snr3_cancel_run(s3run);
 		DEBUG_MSG("set scope %d\n",scope);
 		s3run->scope = scope;
+		if (scope == snr3scope_files) {
+			gtk_label_set_markup(GTK_LABEL(snrwin->warninglabel),_("<span foreground=\"red\"><b>There is no 'undo' when replacing in files.</b>\nBackup files are created as filename~</span>"));
+		} else {
+			gtk_label_set_text(GTK_LABEL(snrwin->warninglabel),NULL);
+		}
 		retval |= 1;
 	}
 	if (type != s3run->type) {
@@ -1363,7 +1394,7 @@ snr3run_init_from_gui(TSNRWin *snrwin, Tsnr3run *s3run)
 			if (cbasedir && cbasedir[0] != '\0')
 				snrwin->bfwin->session->snr3_basedir_history = add_to_history_stringlist(snrwin->bfwin->session->snr3_basedir_history, cbasedir,TRUE);
 		}
-		snrwin->bfwin->session->searchlist = add_to_history_stringlist(snrwin->bfwin->session->searchlist, s3run->query, TRUE);
+		search_add_or_extend_history(snrwin->bfwin, s3run->query);
 		if (s3run->replace && s3run->replace[0] != '\0')
 			snrwin->bfwin->session->replacelist = add_to_history_stringlist(snrwin->bfwin->session->replacelist, s3run->replace,TRUE);
 	}
@@ -1714,35 +1745,44 @@ snr3_advanced_dialog_backend(Tbfwin * bfwin, const gchar *findtext, Tsnr3scope s
 	currentrow++;
 
 	snrwin->showinoutputbox = dialog_check_button_in_table(_("Show results in Output Pane"), bfwin->session->snr3_showinoutputbox, table,
-										0, 4, currentrow, currentrow+1);
+										0, 2, currentrow, currentrow+1);
 	gtk_widget_set_tooltip_text(snrwin->showinoutputbox, _("Show all results in the Output Pane on the bottom of the document list"));
 
-	currentrow++;
-
-	snrwin->ignorebackupfiles = dialog_check_button_in_table(_("Ignore backup files"), bfwin->session->snr3_ignorebackupfiles, table,
-										0, 4, currentrow, currentrow+1);
-	gtk_widget_set_tooltip_text(snrwin->ignorebackupfiles, _("Ignore backup files *~ created by Bluefish"));
+	snrwin->warninglabel = gtk_label_new(NULL);
+	gtk_label_set_line_wrap(GTK_LABEL(snrwin->warninglabel), TRUE);
+#if GTK_CHECK_VERSION(3,2,0)
+	gtk_label_set_width_chars(GTK_LABEL(snrwin->warninglabel),50);
+#endif
+	gtk_misc_set_alignment(GTK_MISC(snrwin->warninglabel),0.5,0.5);
+	gtk_table_attach(GTK_TABLE(table), snrwin->warninglabel, 2, 4, currentrow, currentrow+4, GTK_EXPAND | GTK_FILL,
+					 GTK_FILL, 0, 0);
 
 	currentrow++;
 
 	snrwin->matchCase = dialog_check_button_in_table(_("Case sensitive _matching"), bfwin->session->snr3_casesens, table,
-										0, 4, currentrow, currentrow+1);
+										0, 2, currentrow, currentrow+1);
 	gtk_widget_set_tooltip_text(snrwin->matchCase, _("Only match if case (upper/lower) is identical."));
 
 	currentrow++;
 
 	snrwin->escapeChars = dialog_check_button_in_table(_("Pattern contains escape-se_quences"), bfwin->session->snr3_escape_chars, table,
-										0, 4, currentrow, currentrow+1);
+										0, 2, currentrow, currentrow+1);
 	gtk_widget_set_tooltip_text(snrwin->escapeChars,
 								_("Pattern contains backslash escaped characters such as \\n \\t etc."));
 
 	currentrow++;
 
 	snrwin->dotmatchall = dialog_check_button_in_table(_("Dot character in regex pattern matches newlines"), bfwin->session->snr3_dotmatchall, table,
-										0, 4, currentrow, currentrow+1);
+										0, 2, currentrow, currentrow+1);
 	gtk_widget_set_tooltip_text(snrwin->dotmatchall,
 								_("The . character will match everything including newlines, use for multiline matching."));
 
+	currentrow++;
+
+	snrwin->ignorebackupfiles = dialog_check_button_in_table(_("Ignore backup files"), bfwin->session->snr3_ignorebackupfiles, table,
+										0, 2, currentrow, currentrow+1);
+	gtk_widget_set_tooltip_text(snrwin->ignorebackupfiles, _("Ignore backup files *~ created by Bluefish"));
+
 
 /*	snrwin->overlappingMatches = gtk_check_button_new_with_mnemonic(_("Allow o_verlapping matches"));
 	gtk_box_pack_start(GTK_BOX(vbox2), snrwin->overlappingMatches, FALSE, FALSE, 0);
@@ -1921,6 +1961,7 @@ snr3_run_extern_replace(Tdocument * doc, const gchar * search_pattern, Tsnr3scop
 			g_warning("snr3_run_extern_replace does not support replace in files\n");
 		break;
 	}
+	DEBUG_MSG("snr3_run_extern_replace, call snr3run_free for s3run=%p\n",s3run);
 	snr3run_free(s3run, FALSE, FALSE); /* We do not need to remove hightlights in current_document, so we pass FALSE */
 }
 
